# WrokPlayerAPI

[![npm version](https://img.shields.io/npm/v/workplayerapi.svg?style=flat-square)](https://www.npmjs.org/package/workplayerapi)
[![install size](https://packagephobia.now.sh/badge?p=workplayerapi)](https://packagephobia.now.sh/result?p=workplayerapi)

API para encapsulamento de chamadas REST para o projeto Work Player da Kyros Tecnologias.

## Instalando

Usando npm:

```bash
$ npm install workplayerapi
```

Usando bower:

```bash
$ bower install workplayerapi
```

Usando yarn:

```bash
$ yarn add workplayerapi
```

## Classes

### Card

```js
import { Card } from 'workplayerapi/classes/Card';

let obj = {};
// Criando novo Card
let card = new Card(obj);

console.log(card.cardId);                  // Number
console.log(card.skillId);                 // Number
console.log(card.skillName);               // String
console.log(card.skillDescription);        // String
console.log(card.cardName);                // String
console.log(card.cardDescription);         // String
console.log(card.url);                     // String
console.log(card.attributeDefinitionList); // String
```

### Player

```js
import { Player } from 'workplayerapi/classes/Player';

let obj = {};
// Criando novo Player
let player = new Player(obj);

console.log(player.id);             // Number
console.log(player.name);           // String
console.log(player.birthdate);      // String
console.log(player.zipcode);        // String
console.log(player.email);          // String
console.log(player.cellphone);      // String
console.log(player.landline);       // String
console.log(player.documentNumber); // String
console.log(player.city);           // String
console.log(player.department);     // String
console.log(player.departmentId);   // Number
console.log(player.function);       // String
console.log(player.functionId);     // Number
console.log(player.team);           // String
console.log(player.teamId);         // Number
```

### User

```js
import { User } from 'workplayerapi/classes/User';

let obj = {};
// Criando novo User
let user = new User(obj);

console.log(user.userId);      // Number
console.log(user.username);    // String
console.log(user.name);        // String
console.log(user.displayName); // String
console.log(user.companyId);   // Number
console.log(user.companyName); // String
console.log(user.email);       // String
```

### Task

```js
import { Task } from 'workplayerapi/classes/Task';

let obj = {};
// Criando nova Task
let task = new Task(obj);

console.log(task.id);          // Number
console.log(task.projectId);   // Number
console.log(task.name);        // String
console.log(task.description); // String
console.log(task.duration);    // Number
console.log(task.startedAt);    // Number
console.log(task.expectedAt);  // Number
console.log(task.finalizedAt); // Number
console.log(task.createdAt);   // Number
console.log(task.createdBy);   // String
console.log(task.updatedBy);   // String
console.log(task.status);      // String
console.log(task.card);        // Card
```

## Validações

### E-mail

```js
import { validateEmail } from 'workplayerapi/global/validators';

let email = 'kimr@kyros.com.br';

// Passando o e-mail
if (validateEmail(email)) console.log('E-mail é válido!');
else console.log('E-mail é inválido');
```

### Senha

```js
import { validatePassword } from 'workplayerapi/global/validators';

let email = 'kimr@kyros.com.br';

// Passando o e-mail
if (validatePassword(email)) console.log('Senha é válida!');
else console.log('Senha é inválida');
```

### Usuário autenticado

```js
import { setToken } from 'workplayerapi/config/logged';

// Pegar o token persistido com o Redux
let token = 'token';

setToken(token);
```

## Serviços

### Login

```js
import { makeLogin } from 'workplayerapi/routes/login';

let email = 'kimr@kyros.com.br';
let senha = 'password';

// Passando o e-mail e senha
makeLogin(email, senha)
    .then((result) => {
              if (result.login_success) {
                console.log(JSON.stringify(result.user));
                console.log(JSON.stringify(result.token));
              }
              else console.log(JSON.stringify(result.message));
});
```

#### Retorno
##### Sucesso
```json
{
  "login_success" : true,
  "message"       : null,
  "token"         : "",
  "user"          : {
    "userId"      : 3,
    "username"    : "kimr",
    "name"        : "Kim",
    "displayName" : "Kim Ruan Lopes",
    "companyId"   : 1,
    "companyName" : "KYROS TECNOLOGIA",
    "email"       : "kimr@kyros.com.br",
    "type"        : "MOBILE",
    "sub"         : "192.168.11.23",
    "iat"         : 1567083971,
    "exp"         : 1567084571,
    "iss"         : "http://www.kyros.com.br",
    "permissions" : ["WP.PROJECT.SEARCH","WP.PROJECT.SAVE","WP.PLAYER.SEARCH","WP.PLAYER.SAVE"],
    "scopes"      : ["WP.ADMIN"]
  }
}
```

##### Falha
```json
{
  "login_success" : false,
  "message"       : "AUTHFAILED",
  "token"         : null,
  "user"          : null
}
```

### Players

```js
import { getAllPlayers } from 'workplayerapi/routes/player';

// Passar todos os filtros necessários diretamente pela função
// Caso algum filtro não seja necessário, passar com valor 'null'
let departmentId = 1;
let teamId       = 1;
let name         = "Kim";
let pageSize     = 10;
let page         = 2;
let email        = 'kimr@kyros.com.br';
let functionId   = 1;

getAllPlayers(departmentId, teamId, name, pageSize, page, email, functionId)
    .then((result) => console.log(JSON.stringify(result)));
```

#### Retorno
##### Sucesso
```json
{
  "message"  : null,
  "players"  : [
  {
    "id"             : 1252,
    "name"           : "Kim",
    "birthdate"      : "10/03/1997",
    "zipcode"        : "32608-224",
    "email"          : "kimr@kyros.com.br",
    "cellphone"      : null,
    "landline"       : null,
    "documentNumber" : "38228218930",
    "city"           : "Uberlândia",
    "department"     : "FABRICA",
    "departmentId"   : 3,
    "function"       : "ANALISTA DESENVOLVEDOR",
    "functionId"     : 3,
    "team"           : "Equipe de Desenvolvimento e Projetos Java",
    "teamId"         : 2
  }
  ],
  "newToken" : ""
}
```

##### Falha
```json
{
  "message"  : "",
  "players"  : null,
  "newToken" : null
}
```

### Cards

```js
import { getMyDeck } from 'workplayerapi/routes/cards';

// Ao chamar este serviço será retornado um deck (uma lista de cards)

getMyDeck()
    .then((result) => {
        // Aqui retornará uma mensagem pronta avisando o usuário que seu deck está vazio
        if (result.deck === null) console.log(JSON.stringify(result.message));
        else console.log(JSON.stringify(result.deck));
});
```

#### Retorno
##### Sucesso
```json
{
  "message"  : null,
  "deck"     : [
  {
    "cardId"                  : 11,
    "skillId"                 : 1,
    "skillName"               : "JAVA",
    "skillDescription"        : null,
    "cardName"                : "ReactNative",
    "cardDescription"         : "ReactNative",
    "url"                     : null,
    "attributeDefinitionList" : null
  }
  ],
  "newToken" : ""
}
```

##### Falha
```json
{
  "message"  : "Deck vazio!",
  "deck"     : null,
  "newToken" : null
}
```

### Tasks

```js
import { getTasks } from 'workplayerapi/routes/tasks';

// Ao chamar este serviço será retornado uma lista de tasks

getTasks()
    .then((result) => {
        // Aqui retornará uma mensagem pronta avisando o usuário que não possui mais tasks
        if (result.tasks === null) console.log(JSON.stringify(result.message));
        else console.log(JSON.stringify(result.tasks));
});
```

#### Retorno
##### Sucesso
```json
{
  "message"  : null,
  "tasks"    : {
    "toDo": [
      {
        "task": {
          "id"          : 2341,
          "projectId"   : 94,
          "name"        : "3397 - Melhorias cargas OPL",
          "description" : null,
          "duration"    : 1,
          "startedAt"   : null,
          "expectedAt"  : 1449168900000,
          "finalizedAt" : null,
          "createdAt"   : 1566445276000,
          "createdBy"   : "Tiago",
          "updatedBy"   : null,
          "status"      : "WAITING",
          "card" : {
            "cardId"                  : 12,
            "skillId"                 : 1,
            "skillName"               : "JAVA",
            "skillDescription"        : null,
            "cardName"                : "Flutter",
            "cardDescription"         : "Flutter",
            "url"                     : null,
            "attributeDefinitionList" : null
          }
        }
      }
    ],
    "inProgress": [
      {
        "task"   : {
          "id"          : 2341,
          "projectId"   : 94,
          "name"        : "3397 - Melhorias cargas OPL",
          "description" : null,
          "duration"    : 1,
          "startedAt"   : null,
          "expectedAt"  : 1449168900000,
          "finalizedAt" : null,
          "createdAt"   : 1566445276000,
          "createdBy"   : "Tiago",
          "updatedBy"   : null,
          "status"      : "EXECUTING",
          "card" : {
            "cardId"                  : 12,
            "skillId"                 : 1,
            "skillName"               : "JAVA",
            "skillDescription"        : null,
            "cardName"                : "Flutter",
            "cardDescription"         : "Flutter",
            "url"                     : null,
            "attributeDefinitionList" : null
          }
        }
      }
    ],
    "done": [
      {
        "task"   : {
          "id"          : 2341,
          "projectId"   : 94,
          "name"        : "3397 - Melhorias cargas OPL",
          "description" : null,
          "duration"    : 1,
          "startedAt"   : null,
          "expectedAt"  : 1449168900000,
          "finalizedAt" : null,
          "createdAt"   : 1566445276000,
          "createdBy"   : "Tiago",
          "updatedBy"   : null,
          "status"      : "DONE",
          "card" : {
            "cardId"                  : 12,
            "skillId"                 : 1,
            "skillName"               : "JAVA",
            "skillDescription"        : null,
            "cardName"                : "Flutter",
            "cardDescription"         : "Flutter",
            "url"                     : null,
            "attributeDefinitionList" : null
          }
        }
      }
    ]
  },
  "newToken" : ""
}
```

##### Falha
```json
{
  "message"  : "Você não possui mais atividades!",
  "tasks"    : null,
  "newToken" : null
}
```

###### NOTA
A API está sendo construída aos poucos, portanto qualquer dúvida ou caso seja encontrado algum bug, reportar na seção de Issues.

## Autor

Kim Ruan Lopes - Kyros Tecnologias

## Lisença

MIT
