/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import _ from 'lodash';

import logged, { setToken } from '../config/logged';
import { errorRequestTreatment } from '../global/errors';
import { Task } from '../classes/Task';

const getTasksRequest = () => {
    return logged.get('/job/thisWeek')
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;
            let object  = data.object;

            if (!_.isEmpty(object, true)) {
                let tasks      = {};
                let toDo       = [];
                let inProgress = [];
                let done       = [];
                let token      = _.get(headers, 'x-token');

                object.map(activity => {
                    switch (activity.status) {
                        case 'WAITING':
                            toDo.push(new Task(activity.task));
                            break;

                        case 'EXECUTING':
                            inProgress.push(new Task(activity.task));
                            break;

                        case 'DONE':
                            done.push(new Task(activity.task));
                            break;
                    }
                });

                tasks = {
                    toDo       : toDo,
                    inProgress : inProgress,
                    done       : done
                };

                setToken(token);

                return {
                    result   : 'GET_TASKS_SUCCESS',
                    tasks    : tasks,
                    message  : message,
                    token    : token
                }
            }

            else return {
                result   : 'GET_TASKS_FAIL',
                tasks    : null,
                message  : message === null ? 'Você não possui mais atividades!' : message,
                token    : []
            }
        })
        .catch(error => { return errorRequestTreatment(error, 'GET_TASKS') });
};

export function getTasks() {
    return getTasksRequest()
        .then(async (res) => {
            let result = {};

            if (res.result === 'GET_TASKS_SUCCESS') {
                result = {
                    message  : res.message,
                    tasks    : res.tasks,
                    newToken : res.token
                }
            }
            else if (res.result === 'GET_TASKS_FAIL') {
                result = {
                    message  : res.message,
                    tasks    : null,
                    newToken : null
                }
            }

            return result
        });
}

module.exports = {
    getTasks
};
